"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Boards = void 0;
class Boards {
    constructor(client) {
        this.client = client;
    }
    getBoardMemberships(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/memberships`,
                method: 'GET',
                params: {
                    filter: parameters.filter,
                    activity: parameters.activity,
                    orgMemberType: parameters.orgMemberType,
                    member: parameters.member,
                    member_fields: parameters.memberFields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardMemberships' });
        });
    }
    getBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}`,
                method: 'GET',
                params: {
                    actions: parameters.actions,
                    boardStars: parameters.boardStars,
                    cards: parameters.cards,
                    card_pluginData: parameters.cardPluginData,
                    checklists: parameters.checklists,
                    customFields: parameters.customFields,
                    fields: parameters.fields,
                    labels: parameters.labels,
                    lists: parameters.lists,
                    members: parameters.members,
                    memberships: parameters.memberships,
                    pluginData: parameters.pluginData,
                    organization: parameters.organization,
                    organization_pluginData: parameters.organizationPluginData,
                    myPrefs: parameters.myPrefs,
                    tags: parameters.tags,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoard' });
        });
    }
    updateBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}`,
                method: 'PUT',
                params: {
                    name: parameters.name,
                    desc: parameters.desc,
                    closed: parameters.closed,
                    subscribed: parameters.subscribed,
                    idOrganization: parameters.idOrganization,
                    'prefs/permissionLevel': parameters.permissionLevel,
                    'prefs/selfJoin': parameters.selfJoin,
                    'prefs/cardCovers': parameters.cardCovers,
                    'prefs/hideVotes': parameters.hideVotes,
                    'prefs/invitations': parameters.invitations,
                    'prefs/voting': parameters.voting,
                    'prefs/comments': parameters.comments,
                    'prefs/background': parameters.background,
                    'prefs/cardAging': parameters.cardAging,
                    'prefs/calendarFeedEnabled': parameters.calendarFeedEnabled,
                    'labelNames/green': parameters.green,
                    'labelNames/yellow': parameters.yellow,
                    'labelNames/orange': parameters.orange,
                    'labelNames/red': parameters.red,
                    'labelNames/purple': parameters.purple,
                    'labelNames/blue': parameters.blue,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateBoard' });
        });
    }
    deleteBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}`,
                method: 'DELETE',
                data: parameters.body,
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteBoard' });
        });
    }
    getBoardField(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/${parameters.field}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardField' });
        });
    }
    getBoardActions(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.boardId}/actions`,
                method: 'GET',
                params: {
                    filter: parameters.filter,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardActions' });
        });
    }
    getBoardCard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/cards/${parameters.idCard}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardCard' });
        });
    }
    getBoardStars(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.boardId}/boardStars`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardStars' });
        });
    }
    getBoardChecklists(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/checklists`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardChecklists' });
        });
    }
    createBoardChecklist(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/checklists`,
                method: 'POST',
                params: {
                    name: parameters.name,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createBoardChecklist' });
        });
    }
    getBoardCards(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/cards`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardCards' });
        });
    }
    getBoardCardsFilter(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/cards/${parameters.filter}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardCardsFilter' });
        });
    }
    getBoardCustomFields(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/customFields`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardCustomFields' });
        });
    }
    getBoardLabels(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/labels`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                    limit: parameters.limit,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardLabels' });
        });
    }
    createBoardLabel(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/labels`,
                method: 'POST',
                params: {
                    name: parameters.name,
                    color: parameters.color,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createBoardLabel' });
        });
    }
    getBoardLists(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/lists`,
                method: 'GET',
                params: {
                    cards: parameters.cards,
                    card_fields: parameters.cardFields,
                    filter: parameters.filter,
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardLists' });
        });
    }
    createBoardList(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/lists`,
                method: 'POST',
                params: {
                    name: parameters.name,
                    pos: parameters.pos,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createBoardList' });
        });
    }
    getBoardListsFilter(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/lists/${parameters.filter}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardListsFilter' });
        });
    }
    getBoardMembers(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/members`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getBoardMembers' });
        });
    }
    inviteMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/members`,
                method: 'PUT',
                params: {
                    email: parameters.email,
                    type: parameters.type,
                },
                data: {
                    fullName: parameters.fullName,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'inviteMember' });
        });
    }
    addMemberToBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/members/${parameters.idMember}`,
                method: 'PUT',
                params: {
                    type: parameters.type,
                    allowBillableGuest: parameters.allowBillableGuest,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'addMemberToBoard' });
        });
    }
    removeMemberFromBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/members/${parameters.idMember}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'removeMemberFromBoard' });
        });
    }
    updateMemberOnBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/memberships/${parameters.idMembership}`,
                method: 'PUT',
                params: {
                    type: parameters.type,
                    member_fields: parameters.memberFields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateMemberOnBoard' });
        });
    }
    updateEmailPosition(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/myPrefs/emailPosition`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateEmailPosition' });
        });
    }
    changeEmailList(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/myPrefs/idEmailList`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'changeEmailList' });
        });
    }
    updateShowListGuide(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/myPrefs/showListGuide`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateShowListGuide' });
        });
    }
    updateShowSidebar(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/myPrefs/showSidebar`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateShowSidebar' });
        });
    }
    updateShowSidebarActivity(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/myPrefs/showSidebarActivity`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateShowSidebarActivity' });
        });
    }
    updateShowSidebarBoardActions(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/myPrefs/showSidebarBoardActions`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateShowSidebarBoardActions' });
        });
    }
    updateShowSidebarMembers(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/myPrefs/showSidebarMembers`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateShowSidebarMembers' });
        });
    }
    createBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: '/boards/',
                method: 'POST',
                params: {
                    name: parameters.name,
                    defaultLabels: parameters.defaultLabels,
                    defaultLists: parameters.defaultLists,
                    desc: parameters.desc,
                    idOrganization: parameters.idOrganization,
                    idBoardSource: parameters.idBoardSource,
                    keepFromSource: parameters.keepFromSource,
                    powerUps: parameters.powerUps,
                    prefs_permissionLevel: parameters.prefsPermissionLevel,
                    prefs_voting: parameters.prefsVoting,
                    prefs_comments: parameters.prefsComments,
                    prefs_invitations: parameters.prefsInvitations,
                    prefs_selfJoin: parameters.prefsSelfJoin,
                    prefs_cardCovers: parameters.prefsCardCovers,
                    prefs_background: parameters.prefsBackground,
                    prefs_cardAging: parameters.prefsCardAging,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createBoard' });
        });
    }
    createCalendarKey(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/calendarKey/generate`,
                method: 'POST',
            };
            return this.client.sendRequest(config, callback, { methodName: 'createCalendarKey' });
        });
    }
    createEmailKey(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/emailKey/generate`,
                method: 'POST',
            };
            return this.client.sendRequest(config, callback, { methodName: 'createEmailKey' });
        });
    }
    createIdTags(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/idTags`,
                method: 'POST',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createIdTags' });
        });
    }
    markAsViewed(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/markedAsViewed`,
                method: 'POST',
            };
            return this.client.sendRequest(config, callback, { methodName: 'markAsViewed' });
        });
    }
    createPowerUp(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/powerUps`,
                method: 'POST',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createPowerUp' });
        });
    }
    deletePowerUp(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/powerUps/${parameters.powerUp}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deletePowerUp' });
        });
    }
    getEnabledPowerUps(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/boardPlugins`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getEnabledPowerUps' });
        });
    }
    enablePowerUp(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/boardPlugins`,
                method: 'POST',
                params: {
                    idPlugin: parameters.idPlugin,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'enablePowerUp' });
        });
    }
    disablePowerUp(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/boardPlugins/${parameters.idPlugin}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'disablePowerUp' });
        });
    }
    getPowerUps(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/boards/${parameters.id}/plugins`,
                method: 'GET',
                params: {
                    filter: parameters.filter,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getPowerUps' });
        });
    }
}
exports.Boards = Boards;
