"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cards = void 0;
class Cards {
    constructor(client) {
        this.client = client;
    }
    createCard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: '/cards',
                method: 'POST',
                params: {
                    name: parameters.name,
                    desc: parameters.desc,
                    pos: parameters.pos,
                    due: parameters.due,
                    dueComplete: parameters.dueComplete,
                    idList: parameters.idList,
                    idMembers: parameters.idMembers,
                    idLabels: parameters.idLabels,
                    urlSource: parameters.urlSource,
                    fileSource: parameters.fileSource,
                    idCardSource: parameters.idCardSource,
                    keepFromSource: parameters.keepFromSource,
                    address: parameters.address,
                    locationName: parameters.locationName,
                    coordinates: parameters.coordinates,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createCard' });
        });
    }
    getCard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                    actions: parameters.actions,
                    attachments: parameters.attachments,
                    attachment_fields: parameters.attachmentFields,
                    members: parameters.members,
                    member_fields: parameters.memberFields,
                    membersVoted: parameters.membersVoted,
                    memberVoted_fields: parameters.memberVotedFields,
                    checkItemStates: parameters.checkItemStates,
                    checklists: parameters.checklists,
                    checklist_fields: parameters.checklistFields,
                    board: parameters.board,
                    board_fields: parameters.boardFields,
                    list: parameters.list,
                    pluginData: parameters.pluginData,
                    stickers: parameters.stickers,
                    sticker_fields: parameters.stickerFields,
                    customFieldItems: parameters.customFieldItems,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCard' });
        });
    }
    updateCard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}`,
                method: 'PUT',
                params: {
                    name: parameters.name,
                    desc: parameters.desc,
                    closed: parameters.closed,
                    idMembers: parameters.idMembers,
                    idAttachmentCover: parameters.idAttachmentCover,
                    idList: parameters.idList,
                    idLabels: parameters.idLabels,
                    idBoard: parameters.idBoard,
                    pos: parameters.pos,
                    due: parameters.due,
                    dueComplete: parameters.dueComplete,
                    subscribed: parameters.subscribed,
                    address: parameters.address,
                    locationName: parameters.locationName,
                    coordinates: parameters.coordinates,
                    cover: parameters.cover,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateCard' });
        });
    }
    deleteCard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCard' });
        });
    }
    getCardField(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/${parameters.field}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardField' });
        });
    }
    getCardActions(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/actions`,
                method: 'GET',
                params: {
                    filter: parameters.filter,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardActions' });
        });
    }
    getCardAttachments(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/attachments`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardAttachments' });
        });
    }
    createCardAttachment(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/attachments`,
                method: 'POST',
                params: {
                    name: parameters.name,
                    file: parameters.file,
                    mimeType: parameters.mimeType,
                    url: parameters.url,
                    setCover: parameters.setCover,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createCardAttachment' });
        });
    }
    getCardAttachment(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/attachments/${parameters.idAttachment}`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardAttachment' });
        });
    }
    deleteCardAttachment(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/attachments/${parameters.idAttachment}`,
                method: 'DELETE',
                data: parameters.body,
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCardAttachment' });
        });
    }
    getCardBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/board`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardBoard' });
        });
    }
    getCardCompletedChecklists(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/checkItemStates`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardCompletedChecklists' });
        });
    }
    getCardChecklists(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/checklists`,
                method: 'GET',
                params: {
                    checkItems: parameters.checkItems,
                    checkItem_fields: parameters.checkItemFields,
                    filter: parameters.filter,
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardChecklists' });
        });
    }
    createCardChecklist(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/checklists`,
                method: 'POST',
                params: {
                    name: parameters.name,
                    idChecklistSource: parameters.idChecklistSource,
                    pos: parameters.pos,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createCardChecklist' });
        });
    }
    getCardChecklistItem(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/checkItem/${parameters.idCheckItem}`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardChecklistItem' });
        });
    }
    updateCardCheckItem(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/checkItem/${parameters.idCheckItem}`,
                method: 'PUT',
                params: {
                    name: parameters.name,
                    state: parameters.state,
                    idChecklist: parameters.idChecklist,
                    pos: parameters.pos,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateCardCheckItem' });
        });
    }
    deleteCardChecklistItem(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/checkItem/${parameters.idCheckItem}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCardChecklistItem' });
        });
    }
    getCardList(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/list`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardList' });
        });
    }
    getCardMembers(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/members`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardMembers' });
        });
    }
    getCardMembersVoted(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/membersVoted`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardMembersVoted' });
        });
    }
    voteOnCardForGivenMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/membersVoted`,
                method: 'POST',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'voteOnCardForGivenMember' });
        });
    }
    getCardPluginData(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/pluginData`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardPluginData' });
        });
    }
    getCardStickers(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/stickers`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
                data: parameters.body,
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardStickers' });
        });
    }
    addStickerToCard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/stickers`,
                method: 'POST',
                params: {
                    image: parameters.image,
                    top: parameters.top,
                    left: parameters.left,
                    zIndex: parameters.zIndex,
                    rotate: parameters.rotate,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'addStickerToCard' });
        });
    }
    getCardSticker(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/stickers/${parameters.idSticker}`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardSticker' });
        });
    }
    updateCardSticker(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/stickers/${parameters.idSticker}`,
                method: 'PUT',
                params: {
                    top: parameters.top,
                    left: parameters.left,
                    zIndex: parameters.zIndex,
                    rotate: parameters.rotate,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateCardSticker' });
        });
    }
    deleteCardSticker(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/stickers/${parameters.idSticker}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCardSticker' });
        });
    }
    updateCardComment(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/actions/${parameters.idAction}/comments`,
                method: 'PUT',
                params: {
                    text: parameters.text,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateCardComment' });
        });
    }
    deleteCardComment(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/actions/${parameters.idAction}/comments`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCardComment' });
        });
    }
    updateCardCustomField(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.idCard}/customField/${parameters.idCustomField}/item`,
                method: 'PUT',
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateCardCustomField' });
        });
    }
    getCardCustomFields(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/customFieldItems`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getCardCustomFields' });
        });
    }
    addCardComment(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/actions/comments`,
                method: 'POST',
                params: {
                    text: parameters.text,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'addCardComment' });
        });
    }
    addCardLabel(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/idLabels`,
                method: 'POST',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'addCardLabel' });
        });
    }
    addCardMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/idMembers`,
                method: 'POST',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'addCardMember' });
        });
    }
    createCardLabel(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/labels`,
                method: 'POST',
                params: {
                    color: parameters.color,
                    name: parameters.name,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createCardLabel' });
        });
    }
    markCardNotificationAsRead(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/markAssociatedNotificationsRead`,
                method: 'POST',
            };
            return this.client.sendRequest(config, callback, { methodName: 'markCardNotificationAsRead' });
        });
    }
    deleteCardLabel(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/idLabels/${parameters.idLabel}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCardLabel' });
        });
    }
    deleteCardMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/idMembers/${parameters.idMember}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCardMember' });
        });
    }
    deleteCardMemberVote(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/membersVoted/${parameters.idMember}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCardMemberVote' });
        });
    }
    updateCardChecklistItem(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.idCard}/checklist/${parameters.idChecklist}/checkItem/${parameters.idCheckItem}`,
                method: 'PUT',
                params: {
                    pos: parameters.pos,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateCardChecklistItem' });
        });
    }
    deleteCardChecklist(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/cards/${parameters.id}/checklists/${parameters.idChecklist}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteCardChecklist' });
        });
    }
}
exports.Cards = Cards;
