import * as Models from './models';
import * as Parameters from './parameters';
import { Client } from '../clients';
import { Callback } from '../types';
export declare class Enterprises {
    private client;
    constructor(client: Client);
    /**
     * Get an enterprise by its ID. */
    getEnterprise<T = unknown>(parameters: Parameters.GetEnterprise, callback: Callback<T>): Promise<void>;
    /**
     * Get an enterprise by its ID. */
    getEnterprise<T = unknown>(parameters: Parameters.GetEnterprise, callback?: undefined): Promise<T>;
    /**
     * Returns an array of Actions related to the Enterprise object. Used for populating data sent to Google Sheets from an Enterprise's audit log page: https://trello.com/e/{enterprise_name}/admin/auditlog. An Enterprise admin token is required for this route. */
    getEnterpriseAuditLog<T = unknown>(parameters: Parameters.GetEnterpriseAuditLog, callback?: Callback<T>): Promise<void>;
    /**
     * Returns an array of Actions related to the Enterprise object. Used for populating data sent to Google Sheets from an Enterprise's audit log page: https://trello.com/e/{enterprise_name}/admin/auditlog. An Enterprise admin token is required for this route. */
    getEnterpriseAuditLog<T = unknown>(parameters: Parameters.GetEnterpriseAuditLog, callback?: undefined): Promise<T>;
    /**
     * Get an enterprise's admin members. */
    getEnterpriseAdmins<T = Models.Enterprise>(parameters: Parameters.GetEnterpriseAdmins, callback: Callback<T>): Promise<void>;
    /**
     * Get an enterprise's admin members. */
    getEnterpriseAdmins<T = Models.Enterprise>(parameters: Parameters.GetEnterpriseAdmins, callback?: undefined): Promise<T>;
    /**
     * Get the signup URL for an enterprise. */
    getEnterpriseSignupUrl<T = unknown>(parameters: Parameters.GetEnterpriseSignupUrl, callback: Callback<T>): Promise<void>;
    /**
     * Get the signup URL for an enterprise. */
    getEnterpriseSignupUrl<T = unknown>(parameters: Parameters.GetEnterpriseSignupUrl, callback?: undefined): Promise<T>;
    /**
     * Get the members of an enterprise. */
    getEnterpriseMembers<T = unknown>(parameters: Parameters.GetEnterpriseMembers, callback: Callback<T>): Promise<void>;
    /**
     * Get the members of an enterprise. */
    getEnterpriseMembers<T = unknown>(parameters: Parameters.GetEnterpriseMembers, callback?: undefined): Promise<T>;
    /**
     * Get a specific member of an enterprise by ID. */
    getEnterpriseMember<T = Models.Member>(parameters: Parameters.GetEnterpriseMember, callback: Callback<T>): Promise<void>;
    /**
     * Get a specific member of an enterprise by ID. */
    getEnterpriseMember<T = Models.Member>(parameters: Parameters.GetEnterpriseMember, callback?: undefined): Promise<T>;
    /**
     * Get whether an organization can be transferred to an enterprise. */
    getEnterpriseTransferrableOrganization<T = Models.Organization>(parameters: Parameters.GetEnterpriseTransferrableOrganization, callback: Callback<T>): Promise<void>;
    /**
     * Get whether an organization can be transferred to an enterprise. */
    getEnterpriseTransferrableOrganization<T = Models.Organization>(parameters: Parameters.GetEnterpriseTransferrableOrganization, callback?: undefined): Promise<T>;
    /**
     * Create an auth Token for an Enterprise. */
    createEnterpriseToken<T = unknown>(parameters: Parameters.CreateEnterpriseToken, callback: Callback<T>): Promise<void>;
    /**
     * Create an auth Token for an Enterprise. */
    createEnterpriseToken<T = unknown>(parameters: Parameters.CreateEnterpriseToken, callback?: undefined): Promise<T>;
    /**
     * Transfer an organization to an enterprise. */
    transferOrganizationToEnterprise<T = unknown>(parameters: Parameters.TransferOrganizationToEnterprise, callback: Callback<T>): Promise<void>;
    /**
     * Transfer an organization to an enterprise. */
    transferOrganizationToEnterprise<T = unknown>(parameters: Parameters.TransferOrganizationToEnterprise, callback?: undefined): Promise<T>;
    /**
     * This endpoint is used to update whether the provided Member should use one of the Enterprise's available licenses or not. */
    updateEnterpriseMemberLicense<T = Models.Member>(parameters: Parameters.UpdateEnterpriseMemberLicense, callback: Callback<T>): Promise<void>;
    /**
     * This endpoint is used to update whether the provided Member should use one of the Enterprise's available licenses or not. */
    updateEnterpriseMemberLicense<T = Models.Member>(parameters: Parameters.UpdateEnterpriseMemberLicense, callback?: undefined): Promise<T>;
    /**
     * Deactivate a Member of an Enterprise. */
    deactivateEnterpriseMember<T = unknown>(parameters: Parameters.DeactivateEnterpriseMember, callback: Callback<T>): Promise<void>;
    /**
     * Deactivate a Member of an Enterprise. */
    deactivateEnterpriseMember<T = unknown>(parameters: Parameters.DeactivateEnterpriseMember, callback?: undefined): Promise<T>;
    /**
     * Make Member an admin of Enterprise. */
    makeEnterpriseMemberAdmin<T = unknown>(parameters: Parameters.MakeEnterpriseMemberAdmin, callback: Callback<T>): Promise<void>;
    /**
     * Make Member an admin of Enterprise. */
    makeEnterpriseMemberAdmin<T = unknown>(parameters: Parameters.MakeEnterpriseMemberAdmin, callback?: undefined): Promise<T>;
    /**
     * Remove an organization from an enterprise. */
    deleteEnterpriseOrganization<T = unknown>(parameters: Parameters.DeleteEnterpriseOrganization, callback: Callback<T>): Promise<void>;
    /**
     * Remove an organization from an enterprise. */
    deleteEnterpriseOrganization<T = unknown>(parameters: Parameters.DeleteEnterpriseOrganization, callback?: undefined): Promise<T>;
    /**
     * Remove an member as admin from an enterprise. */
    deleteEnterpriseMemberAdmin<T = unknown>(parameters: Parameters.DeleteEnterpriseMemberAdmin, callback: Callback<T>): Promise<void>;
    /**
     * Remove an member as admin from an enterprise. */
    deleteEnterpriseMemberAdmin<T = unknown>(parameters: Parameters.DeleteEnterpriseMemberAdmin, callback?: undefined): Promise<T>;
}
