"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Enterprises = void 0;
class Enterprises {
    constructor(client) {
        this.client = client;
    }
    getEnterprise(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                    members: parameters.members,
                    member_fields: parameters.memberFields,
                    member_filter: parameters.memberFilter,
                    member_sort: parameters.memberSort,
                    member_sortBy: parameters.memberSortBy,
                    member_sortOrder: parameters.memberSortOrder,
                    member_startIndex: parameters.memberStartIndex,
                    member_count: parameters.memberCount,
                    organizations: parameters.organizations,
                    organization_fields: parameters.organizationFields,
                    organization_paid_accounts: parameters.organizationPaidAccounts,
                    organization_memberships: parameters.organizationMemberships,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getEnterprise' });
        });
    }
    getEnterpriseAuditLog(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/auditlog`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getEnterpriseAuditLog' });
        });
    }
    getEnterpriseAdmins(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/admins`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getEnterpriseAdmins' });
        });
    }
    getEnterpriseSignupUrl(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/signupUrl`,
                method: 'GET',
                params: {
                    authenticate: parameters.authenticate,
                    confirmationAccepted: parameters.confirmationAccepted,
                    returnUrl: parameters.returnUrl,
                    tosAccepted: parameters.tosAccepted,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getEnterpriseSignupUrl' });
        });
    }
    getEnterpriseMembers(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/members`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                    filter: parameters.filter,
                    sort: parameters.sort,
                    sortBy: parameters.sortBy,
                    sortOrder: parameters.sortOrder,
                    startIndex: parameters.startIndex,
                    count: parameters.count,
                    organization_fields: parameters.organizationFields,
                    board_fields: parameters.boardFields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getEnterpriseMembers' });
        });
    }
    getEnterpriseMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/members/${parameters.idMember}`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                    organization_fields: parameters.organizationFields,
                    board_fields: parameters.boardFields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getEnterpriseMember' });
        });
    }
    getEnterpriseTransferrableOrganization(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/transferrable/organization/${parameters.idOrganization}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getEnterpriseTransferrableOrganization' });
        });
    }
    createEnterpriseToken(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/tokens`,
                method: 'POST',
                params: {
                    expiration: parameters.expiration,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createEnterpriseToken' });
        });
    }
    transferOrganizationToEnterprise(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/organizations`,
                method: 'PUT',
                params: {
                    idOrganization: parameters.idOrganization,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'transferOrganizationToEnterprise' });
        });
    }
    updateEnterpriseMemberLicense(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/members/${parameters.idMember}/licensed`,
                method: 'PUT',
                params: {
                    Values: parameters.values,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateEnterpriseMemberLicense' });
        });
    }
    deactivateEnterpriseMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/members/${parameters.idMember}/deactivated`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                    fields: parameters.fields,
                    organization_fields: parameters.organizationFields,
                    board_fields: parameters.boardFields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'deactivateEnterpriseMember' });
        });
    }
    makeEnterpriseMemberAdmin(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/admins/${parameters.idMember}`,
                method: 'PUT',
            };
            return this.client.sendRequest(config, callback, { methodName: 'makeEnterpriseMemberAdmin' });
        });
    }
    deleteEnterpriseOrganization(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/organizations/${parameters.idOrg}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteEnterpriseOrganization' });
        });
    }
    deleteEnterpriseMemberAdmin(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/enterprises/${parameters.id}/organizations/${parameters.idMember}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteEnterpriseMemberAdmin' });
        });
    }
}
exports.Enterprises = Enterprises;
