"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Organizations = void 0;
class Organizations {
    constructor(client) {
        this.client = client;
    }
    createOrganization(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: '/organizations',
                method: 'POST',
                params: {
                    displayName: parameters.displayName,
                    desc: parameters.desc,
                    name: parameters.name,
                    website: parameters.website,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'createOrganization' });
        });
    }
    getOrganization(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganization' });
        });
    }
    updateOrganization(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}`,
                method: 'PUT',
                params: {
                    name: parameters.name,
                    displayName: parameters.displayName,
                    desc: parameters.desc,
                    website: parameters.website,
                    'prefs/associatedDomain': parameters.associatedDomain,
                    'prefs/externalMembersDisabled': parameters.externalMembersDisabled,
                    'prefs/googleAppsVersion': parameters.googleAppsVersion,
                    'prefs/boardVisibilityRestrict/org': parameters.org,
                    'prefs/boardVisibilityRestrict/private': parameters.private,
                    'prefs/boardVisibilityRestrict/public': parameters.public,
                    'prefs/orgInviteRestrict': parameters.orgInviteRestrict,
                    'prefs/permissionLevel': parameters.permissionLevel,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateOrganization' });
        });
    }
    deleteOrganization(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteOrganization' });
        });
    }
    getOrganizationField(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/${parameters.field}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationField' });
        });
    }
    getOrganizationActions(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/actions`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationActions' });
        });
    }
    getOrganizationBoards(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/boards`,
                method: 'GET',
                params: {
                    filter: parameters.filter,
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationBoards' });
        });
    }
    getOrganizationExports(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/exports`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationExports' });
        });
    }
    exportOrganizationCSV(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/exports`,
                method: 'POST',
                params: {
                    attachments: parameters.attachments,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'exportOrganizationCSV' });
        });
    }
    getOrganizationMembers(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationMembers' });
        });
    }
    updateOrganizationMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members`,
                method: 'PUT',
                params: {
                    email: parameters.email,
                    fullName: parameters.fullName,
                    type: parameters.type,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateOrganizationMember' });
        });
    }
    getOrganizationMemberships(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/memberships`,
                method: 'GET',
                params: {
                    filter: parameters.filter,
                    member: parameters.member,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationMemberships' });
        });
    }
    getOrganizationMembership(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/memberships/${parameters.idMembership}`,
                method: 'GET',
                params: {
                    member: parameters.member,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationMembership' });
        });
    }
    getOrganizationPluginData(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/pluginData`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationPluginData' });
        });
    }
    getOrganizationTags(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/tags`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationTags' });
        });
    }
    createOrganizationTag(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/tags`,
                method: 'POST',
            };
            return this.client.sendRequest(config, callback, { methodName: 'createOrganizationTag' });
        });
    }
    addOrganizationMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members/${parameters.idMember}`,
                method: 'PUT',
                params: {
                    type: parameters.type,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'addOrganizationMember' });
        });
    }
    deleteOrganizationMember(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members/${parameters.idMember}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteOrganizationMember' });
        });
    }
    updateOrganizationDeactivateStatus(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members/${parameters.idMember}/deactivated`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'updateOrganizationDeactivateStatus' });
        });
    }
    setOrganizationLogo(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/logo`,
                method: 'POST',
                params: {
                    file: parameters.file,
                },
            };
            return this.client.sendRequest(config, callback, { methodName: 'setOrganizationLogo' });
        });
    }
    deleteOrganizationLogo(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/logo`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteOrganizationLogo' });
        });
    }
    deleteOrganizationMemberFromAll(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members/${parameters.idMember}/all`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteOrganizationMemberFromAll' });
        });
    }
    deleteOrganizationAssociatedDomain(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/prefs/associatedDomain`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteOrganizationAssociatedDomain' });
        });
    }
    deleteOrganizationInvites(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/prefs/orgInviteRestrict`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteOrganizationInvites' });
        });
    }
    deleteOrganizationTag(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/tags/${parameters.idTag}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback, { methodName: 'deleteOrganizationTag' });
        });
    }
    getOrganizationNewBillableGuestBoard(parameters, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/newBillableGuests/${parameters.idBoard}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback, { methodName: 'getOrganizationNewBillableGuestBoard' });
        });
    }
}
exports.Organizations = Organizations;
