"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseClient = void 0;
const axios_1 = require("axios");
const telemetry_trello_js_1 = require("telemetry.trello.js");
class BaseClient {
    constructor(config) {
        this.config = config;
        this.telemetryClient = new telemetry_trello_js_1.TelemetryClient(config.telemetry);
        this.instance = axios_1.default.create(Object.assign(Object.assign({ paramsSerializer: this.paramSerializer.bind(this) }, config.baseRequestConfig), { baseURL: 'https://api.trello.com/1' }));
    }
    paramSerializer(parameters) {
        const parts = [];
        Object.entries(parameters).forEach(([key, value]) => {
            if (value === null || typeof value === 'undefined') {
                return undefined;
            }
            if (Array.isArray(value)) {
                // eslint-disable-next-line no-param-reassign
                value = value.join(',');
            }
            if (value instanceof Date) {
                // eslint-disable-next-line no-param-reassign
                value = value.toISOString();
            }
            else if (value !== null && typeof value === 'object') {
                // eslint-disable-next-line no-param-reassign
                value = JSON.stringify(value);
            }
            parts.push(`${this.encode(key)}=${this.encode(value)}`);
            return undefined;
        });
        return parts.join('&');
    }
    encode(value) {
        return encodeURIComponent(value)
            .replace(/%3A/gi, ':')
            .replace(/%24/g, '$')
            .replace(/%2C/gi, ',')
            .replace(/%20/g, '+')
            .replace(/%5B/gi, '[')
            .replace(/%5D/gi, ']');
    }
    sendRequest(rawRequestConfig, callback, telemetryData) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        return __awaiter(this, void 0, void 0, function* () {
            const startDateTime = new Date();
            const requestConfig = Object.assign(Object.assign({}, rawRequestConfig), { params: Object.assign(Object.assign({}, rawRequestConfig.params), { key: this.config.key, token: this.config.token }) });
            const telemetry = Object.assign({ authenticated: !!(this.config.key && this.config.token), bodyExists: !!requestConfig.data, callbackUsed: !!callback, libVersion: '1.0.2', libVersionHash: 'f4e69ca8f831aaadd35a8e11e645ddd3', methodName: (telemetryData === null || telemetryData === void 0 ? void 0 : telemetryData.methodName) || 'sendRequest', onErrorMiddlewareUser: !!((_a = this.config.middlewares) === null || _a === void 0 ? void 0 : _a.onError), onResponseMiddlewareUsed: !!((_b = this.config.middlewares) === null || _b === void 0 ? void 0 : _b.onResponse), queryExists: !!requestConfig.params, requestStartTime: startDateTime, requestEndTime: new Date(), requestStatusCode: 0, timeout: ((_c = this.config.baseRequestConfig) === null || _c === void 0 ? void 0 : _c.timeout) || this.instance.defaults.timeout || -1 }, telemetryData);
            try {
                const response = yield this.instance.request(requestConfig);
                const callbackResponseHandler = callback && ((data) => callback(null, data));
                const defaultResponseHandler = (data) => data;
                const responseHandler = callbackResponseHandler !== null && callbackResponseHandler !== void 0 ? callbackResponseHandler : defaultResponseHandler;
                (_e = (_d = this.config.middlewares) === null || _d === void 0 ? void 0 : _d.onResponse) === null || _e === void 0 ? void 0 : _e.call(_d, response.data);
                telemetry.requestStatusCode = response.status;
                return responseHandler(response.data);
            }
            catch (e) {
                const callbackErrorHandler = callback && ((error) => callback(error));
                const defaultErrorHandler = (error) => {
                    throw error;
                };
                const errorHandler = callbackErrorHandler !== null && callbackErrorHandler !== void 0 ? callbackErrorHandler : defaultErrorHandler;
                (_g = (_f = this.config.middlewares) === null || _f === void 0 ? void 0 : _f.onError) === null || _g === void 0 ? void 0 : _g.call(_f, e);
                telemetry.requestStatusCode = (_j = (_h = e.response) === null || _h === void 0 ? void 0 : _h.status) !== null && _j !== void 0 ? _j : 0;
                return errorHandler(e);
            }
            finally {
                telemetry.requestEndTime = new Date();
                this.telemetryClient.sendTelemetry(telemetry);
            }
        });
    }
}
exports.BaseClient = BaseClient;
